@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: widget.py 5001 2020-03-26 14:34:16Z roger.ineichen $
+$Id: widget.py 5034 2020-06-16 11:22:36Z roger.ineichen $
 """
 __docformat__ = "reStructuredText"
 
@@ -164,7 +164,7 @@ def j01DatePickerJavaScript(j01DatePickerExpression, data):
 # date widget
 class ZebraDatePickerWidgetBase(z3c.form.browser.widget.HTMLTextInputWidget,
     z3c.form.widget.Widget):
-    """Upload widget implementation."""
+    """Date picker widget widget"""
 
     klass = u'j01ZebraDatePickerWidget'
     css = u'j01-datepicker-zebra'
